﻿using CMS.DataEngine;
using CMS.Helpers;
using CMS.Polls;
using CMS.PortalControls;
using System;
using System.Collections.Generic;

namespace Custom
{
    public partial class PollChart : CMSAbstractWebPart
    {
        #region Member Variables
        public string strPollName = "";
        public string strPollAnswers = "";
        public bool blnShowLegend = false;
        #endregion

        #region "Properties"

        /// <summary>
        /// Gets / Sets the poll to chart
        /// </summary>
        public string PollCodeName
        {
            get
            {
                return ValidationHelper.GetString(GetValue("PollCodeName"), "");
            }
            set
            {
                SetValue("PollCodeName", value);
            }
        }

        /// Determines whether the legend is displaed
        /// </summary>
        public bool PollShowLegend
        {
            get
            {
                return ValidationHelper.GetBoolean(GetValue("PollShowLegend"), false);
            }
            set
            {
                SetValue("PollShowLegend", value);
            }
        }


        #endregion


        /// <summary>
        /// Content loaded event handler.
        /// </summary>
        public override void OnContentLoaded()
        {
            base.OnContentLoaded();
            SetupControl();
        }


        /// <summary>
        /// Initializes the control properties.
        /// </summary>
        protected void SetupControl()
        {
            if (StopProcessing)
            {
                // Do nothing
            }
            else
            {
                blnShowLegend = this.PollShowLegend;
                if (this.PollCodeName != "")
                {
                    // Get the poll information
                    PollInfo poll = PollInfoProvider.GetPollInfo(this.PollCodeName, CurrentSite.SiteID);
                    if (poll != null)
                    {
                        strPollName = poll.PollQuestion;

                        // Gets the poll's answers
                        InfoDataSet<PollAnswerInfo> pollanswers = PollAnswerInfoProvider.GetAnswers(poll.PollID);

                        // Get the total number of answers for the poll
                        int intAnswerCount = ValidationHelper.GetInteger(pollanswers.Tables[0].Compute("Sum(AnswerCount)", ""), 0);

                        if (intAnswerCount > 0)
                        {
                            var list = new List<string>();

                            // Loops through individual poll answers
                            foreach (PollAnswerInfo pollanswer in pollanswers)
                            {
                                list.Add("{name: '" + pollanswer.AnswerText + "',y:" + Math.Round(ValidationHelper.GetDouble((ValidationHelper.GetDouble(pollanswer.AnswerCount, 0) / ValidationHelper.GetDouble(intAnswerCount, 0)) * 100, 0), 2) + "}");                            
                            }

                            // Set the chart series data
                            strPollAnswers = String.Join(",", list.ToArray());
                        }
                    }
                }
            }
        }


        /// <summary>
        /// Reload data.
        /// </summary>
        public override void ReloadData()
        {
            base.ReloadData();
            SetupControl();
        }
    }

    public class PollChartAnswer
    {
        public string PollAnswerText { get; set; }
        public double PollAnswerPercentage { get; set; }
    }
}